import  {useState, useEffect } from 'react'
import { OrderService } from 'services'
import { Order } from 'Order'

enum ResStatus {
    IDLE = "IDLE",
    FETCHING = "FETCHING",
    SUCCESS = "SUCCESS",
    ERROR = "ERROR"
}

const useOrder = (orderId: string) => {
    const [status, setStatus] = useState<ResStatus>(ResStatus.IDLE);
    const [data, setData] = useState<Order | null>(null);
    const [error, setError] = useState(null);

    useEffect(() => {
    
        const fetchOrders = async () => {
            setStatus(ResStatus.FETCHING);
            try {
                const orderData = await OrderService.orderById(orderId)
                setData(orderData);
                setStatus(ResStatus.SUCCESS)
            } catch (err) {
                setError(err)
                setStatus(ResStatus.ERROR);
            }
        };

        fetchOrders();
    }, [orderId]);

    return { status, data, order: data, error, ResStatus };
};

export default useOrder;